% Script: PlotUHS.m
% Plot UHS for one location from the database of EFEHR.org
%
% Copyright (C) by J. Woessner
% 12.08.2013
% j.woessner@sed.ethz.ch
%
%% Licence
% SHARE data and products are released under the Creative Commons 
% Attribution-ShareAlike 3.0 Unported (CC BY-SA 3.0) licence.
%  
% For all SHARE datasets the following notice applies and/or is included within the files:
%  
% Copyright ? 2013, ETH Zurich on behalf of the EU-FP7 Consortium of SHARE
% 
% You may use this work under the terms of the CC BY-SA 3.0 (unported) 
% [http://creativecommons.org/licenses/by-sa/3.0/]
% 
% THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. INSOFAR 
% AS THIS WORK IS PROTECTED BY LAWS THAT NEIGHBOUR OR ARE SIMILARLY RELATED
% TO COPYRIGHT, SUCH AS DATABASE RIGHTS AS INTRODUCED IN EUROPE BY THE  
% DIRECTIVE 96/9/EC, YOU ALSO MAY USE THIS WORK UNDER THE TERMS OF 
% CC-BY-SA 3.0 (unported).
% 
% ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR 
% DIRECTLY ALLOWED BY THE APPLICABLE LAW IS PROHIBITED.
% 
% If you alter, transform, or build upon this work, you may distribute the 
% resulting work only under the same or similar license to this one. 
% 
% If you have any questions, or if you wish to seek permission to use this 
% data beyond what is offered by CC BY-SA 3.0 (unported), please contact 
% representatives of the EU-FP7 SHARE consortium at: 
% 
%  
% ETH Zurich / Swiss Seismological Service
% Sonneggstrasse 5
% CH-8092 Zurich, Switzerland
% email: share@sed.ethz.ch
% Tel.: +41-44-633-2179

%% Set Path

sPath=pwd;
addpath(genpath(sPath))

% Define coordinate and IMT
fLon = 0.39;
fLat=46.27;
sIMT='SA';
fPoE = 0.39;
fPeriod = 50;
sSoilType = 'rock';
sAggregationType = 'arithmetic';
fAggLevel = 0.5;

% Get data from database
%[vPeriod, vAcc,sLoc] = GetEfehrHazCurve(fLon,fLat,sIMT,'rock','arithmetic',0.5);
[vPeriod, vAcc,sLoc] = GetEfehrUhs(fLon,fLat,sIMT,fPoE,fPeriod,sSoilType,sAggregationType,fAggLevel);

% Prepare plot
vPeriod = str2num(vPeriod);
vPeriod = vPeriod';
vAcc=str2num(vAcc)';
vLoc = str2num(sLoc);

% For Annotation convert to percentage
fProz=fPoE*100;

% Plot
figure
semilogy(vPeriod,vAcc,'Linewidth',2,'Marker','o','Markersize',5,'Color',[0 0 0],'MarkerFaceColor',[0.5 0.5 0.5])
legend('Mean')
xlabel('Period / [s]','Fontsize',12,'Fontweight','bold')
ylabel('Spectral Acceleration / [g]','Fontsize',12,'Fontweight','bold')
sText = ['Location: Lon=' num2str(roundn(vLoc(1,1),-2)) ', Lat=' num2str(roundn(vLoc(1,2),-2)) ];
text(0.2,0.00015,sText,'Fontsize',10,'Fontweight','bold')
sTitle = [num2str(fProz) '% Prob. of Exceedance in ' num2str(fPeriod) ' years'];
title(sTitle,'Fontsize',12,'Fontweight','bold')
ylim([0.0001 1])
grid on
box on

% Print
sString = ['UHS_' num2str(fProz) '%_in_' num2str(fPeriod) 'years_Location_' num2str(fLon) '_' num2str(fLat) '.eps'];
print('-depsc',sString)

